# Pixar Js

[![PyPi version](https://img.shields.io/pypi/v/pxr-js.svg?logo=pypi&label=PyPI&logoColor=gold)](https://pypi.python.org/pypi/pxr-js)
[![CMake](https://img.shields.io/badge/CMake-3.21...3.31-blue.svg?logo=CMake&logoColor=blue)](https://cmake.org)
[![Linux](https://github.com/untwine/pxr-js/actions/workflows/linux.yml/badge.svg?branch=main)](https://github.com/untwine/pxr-arch/actions/workflows/linux.yml)
[![MacOs](https://github.com/untwine/pxr-js/actions/workflows/macos.yml/badge.svg?branch=main)](https://github.com/untwine/pxr-arch/actions/workflows/macos.yml)
[![Windows](https://github.com/untwine/pxr-js/actions/workflows/windows.yml/badge.svg?branch=main)](https://github.com/untwine/pxr-arch/actions/workflows/windows.yml)
[![License](https://img.shields.io/badge/License-TOST-yellow.svg)](https://github.com/untwine/pxr-js/blob/main/LICENSE.txt)

JSON interface library used in OpenUSD.

This repository is a decoupled version of the "js" library from the
[OpenUSD](https://graphics.pixar.com/usd/release/index.html) library, created
by Pixar.

It is regularly rebased over the "release" branch of the original
[repository](https://github.com/PixarAnimationStudios/OpenUSD) to provide
explicit divergence information from the latest updates and is currently
synchronized with
[v25.05.01](https://github.com/PixarAnimationStudios/OpenUSD/releases/tag/v25.05.01).
